# Intro
## User Accounts

All Satori CI users get the common benefits of the platform:
- [Run](mode_run.md)
- [CI](mode_ci.md)
- [Monitor](mode_monitor.md)
- [Notifications](notifications.md)
- Multiple UIs ([CLI](https://github.com/satorici/satori-cli), [Web](https://www.satori-ci.com), Grafana, [API](http://api.satori-ci.com/schema/swagger)
- [Playbook Marketplace](https://github.com/satorici/playbooks)

The difference between account roles is related to the amount of daily executions, availability and type of testing support that is required:

| Name       |               Daily Executions |                              Monthly Fee | Support                                          |
|------------|--------------------------------|------------------------------------------|--------------------------------------------------|
| Free *     |                             10 |                                        0 | [Discord](https://discord.gg/F6Uzz7fc2s) Support | 
| User       |                           1000 |                                   20 USD | [Email](support@satori-ci.com) Support           |
| Pro        |                           5000 |                                  100 USD | Live Human Support                               |
| Enterprise | 5000 per account (shared pool) | [Contact Us](mailto:sales@satori-ci.com) | Testing as a Service Support                     |

* Free user accounts' instances cannot perform internet connections
